"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FullBlock = exports.HalfBlock = exports.PageHolder = exports.ContentWrapper = exports.SimpleContentWrapper = exports.BasicContentWrapper = exports.Div = exports.SubContent = exports.Content = exports.FlexContainer = exports.Container = exports.Right = exports.Left = exports.Center = exports.Wrapper = exports.LayoutWrapper = exports.Form = void 0;
const styled_components_1 = __importDefault(require("styled-components"));
const config_1 = require("../../utils/config");
exports.Form = styled_components_1.default.form `
  ${(props) => (0, config_1.baseConfig)(props)}
  display: flex;
  flex-direction: column;
  width: 100%;
`;
exports.LayoutWrapper = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  background: ${(props) => props.theme.background};
  flex-direction: row;
  display: flex;
  flex-wrap: wrap;
  align-items: center;
  width: 100%;
  padding-top: 80px;
  padding-bottom: 160px;
  padding-left: 15px;
  padding-right: 15px;
  ::-webkit-scrollbar-track {
    background-color: ${(props) => props.theme.track || '#0E0E0E'};
    position: absolute;
  }

  ::-webkit-scrollbar {
    width: 0.6vw;
  }

  ::-webkit-scrollbar-thumb {
    background-color: ${(props) => props.theme.primary};
  }
`;
exports.Wrapper = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  height: 100%;
  width: 100%;
  ${(props) => props.isBackground && `background: ${props.theme.background};`}
`;
exports.Center = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  margin: auto;
  width: fit-content;
  padding: 10px;
`;
exports.Left = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  display: flex;
  flex-direction: column;
  min-width: 400px;
  /* border-right: 1px solid ${(props) => props.theme.holder}; */
  padding-right: 50px;
  padding-left: 50px;

  @media screen and (max-width: ${(props) => props.mediumMaxWidth || '1000px'}) {
    border: 0;
    padding: 100px 25px 25px;
    align-self: center;
  }

  @media screen and (max-width: ${(props) => props.smallMaxWidth || '500px'}) {
    border: 0;
    padding: 100px 15px 15px;
    min-width: 200px;
    align-self: center;
  }
`;
exports.Right = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  padding-right: 50px;
  padding-left: 50px;
  display: flex;
  flex-direction: column;
  // width: 600px;

  @media screen and (max-width: ${(props) => props.maxWidth || '1000px'}) {
    // width: 464px;
    max-width: 100%;
    padding: 15px 25px 25px;
    align-self: center;
  }
`;
exports.Container = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  width: 100%;
  min-height: 100vh;
  max-width: 100%;
  background: ${(props) => props.theme.background};
`;
exports.FlexContainer = (0, styled_components_1.default)(exports.Container) `
  height: auto;
  min-height: auto;
  background: transparent;
  display: block;
`;
exports.Content = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  z-index: 10;
  position: relative;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
`;
exports.SubContent = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  display: flex;
  -webkit-box-pack: center;
  -webkit-justify-content: center;
  -ms-flex-pack: center;
  justify-content: center;
`;
exports.Div = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  padding-left: 5vw;
  padding-right: 5vw;
`;
exports.BasicContentWrapper = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  position: relative;
  text-align: center;
  top: 0;
  margin-top:70px;
  padding-bottom: 56.25%; /* 16:9 */
  iframe {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
  }
`;
exports.SimpleContentWrapper = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  display: flex;
  justify-content: center;

  @media screen and (max-width: 1000px) {
    flex-direction: column-reverse;
    align-items: center;
  }
`;
exports.ContentWrapper = styled_components_1.default.div `
  ${(props) => (0, config_1.baseConfig)(props)}
  padding: 160px 24px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: flex-start;
  margin: 0 auto;
`;
exports.PageHolder = styled_components_1.default.div `
  width: 100%;

  ul {
    width: 100%;
    display: flex;
    justify-content: center;
  }

  li {
    display: block;
    margin: 2px;
    padding: 2px;
  }

  color: ${(props) => props.theme.primary};
`;
exports.HalfBlock = styled_components_1.default.div `
  width: 50%;
  box-sizing: border-box;
  float: left;
  padding: 10px;
  @media screen and (max-width: 500px) {
    width: 100%;
    float: none;
  }
`;
exports.FullBlock = styled_components_1.default.div `
  padding: 4px;
  margin: 3px;
  border-radius: 6px;
  background-color: #dedede;
  width: 130px;
  display: inline-block;
  b {
    font-size: 10px;
    display: block;
    text-align: center;
  }
  span {
    width: 100%;
    display: block;
    text-align: center;
    margin-top: 5px;
  }
`;
//# sourceMappingURL=index.js.map