"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getValues = void 0;
const react_usestateref_1 = __importDefault(require("react-usestateref"));
const getValues = (object) => {
    const values = [];
    if (object)
        Object.keys(object).forEach((key) => {
            values.push(object[key].value);
        });
    return values;
};
exports.getValues = getValues;
const removeElement = (current, index) => {
    if (current != undefined) {
        if (Array.isArray(current)) {
            current?.splice?.(index != undefined ?
                (typeof index === 'number' ? index : 0) :
                0, 1);
            return current;
        }
        else if (typeof current === 'object') {
            delete current[index || 0];
            return current;
        }
    }
    return current;
};
const flat = (object) => {
    if (object != undefined) {
        if (Array.isArray(object)) {
            return object.flat();
        }
        else if (typeof object === 'object') {
            return Object.values(object);
        }
    }
    return [];
};
const flatAll = (object) => {
    if (object != undefined) {
        let array = undefined;
        if (Array.isArray(object)) {
            array = object;
        }
        else if (typeof object === 'object') {
            array = Object.values(object);
        }
        else {
            return [object];
        }
        const first = array[0];
        if (Array.isArray(first) || typeof first === 'object')
            return flat(array.map(anObject => flatAll(anObject)));
        else
            return [object];
    }
    return [];
};
const retriveIndexes = (indexes, current, last) => {
    if (indexes && indexes.length > 0) {
        return indexes;
    }
    else {
        if (Array.isArray(current)) {
            return last ? [current.length - 1] : [0];
        }
        else {
            const keys = Object.keys(current);
            const lastKey = keys[keys.length - 1];
            const firstKey = keys[0];
            return last ? [lastKey] : [firstKey];
        }
    }
};
const useObjectState = (object) => {
    const [state, setState] = (0, react_usestateref_1.default)(object);
    // console.log('useObjectState', state);
    const update = (indexes, value, current, root) => {
        // console.log('update object current:', current);
        current = current || JSON.parse(JSON.stringify(state));
        root = root || current;
        // console.log('update object:', indexes, value, current, root);
        indexes = retriveIndexes(indexes, current, true);
        if (indexes && indexes.length > 0) {
            if (indexes.length > 1) {
                const newCurrent = current[indexes[0]];
                indexes?.splice?.(0, 1);
                return update(indexes, value, newCurrent, root);
            }
            else {
                current[indexes[0]] = value;
                const newState = JSON.parse(JSON.stringify(root));
                setState(newState);
                return newState;
            }
        }
        return root;
    };
    const remove = (indexes, current, root) => {
        current = current || JSON.parse(JSON.stringify(state));
        root = root || current;
        indexes = retriveIndexes(indexes, current, true);
        if (indexes && indexes.length > 0) {
            if (indexes.length > 1) {
                const newCurrent = current[indexes[0]];
                indexes?.splice?.(0, 1);
                return remove(indexes, newCurrent, root);
            }
            else {
                removeElement(current, indexes[0]);
                const newState = JSON.parse(JSON.stringify(root));
                setState(newState);
                return newState;
            }
        }
        return root;
    };
    const add = (indexes, value, current, root) => {
        current = current || JSON.parse(JSON.stringify(state));
        root = root || current;
        indexes = retriveIndexes(indexes, current, true);
        if (indexes && indexes.length > 0) {
            if (indexes.length > 1) {
                const newCurrent = current[indexes[0]];
                indexes?.splice?.(0, 1);
                return add(indexes, value, newCurrent, root);
            }
            else {
                if (Array.isArray(current)) {
                    current.push(value);
                }
                else {
                    current[indexes[0]] = value;
                }
                const newState = JSON.parse(JSON.stringify(root));
                setState(newState);
                return newState;
            }
        }
        return root;
    };
    // useEffect(() => {
    //   setState(object);
    // }, [object]);
    // console.log('useObjectState', state, setState, add, update, remove);
    return [state, setState, add, update, remove];
};
exports.default = useObjectState;
//# sourceMappingURL=useObjectState.js.map