"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStorageToken = exports.catalog = exports.signOut = exports.isSignedIn = exports.createUserContext = exports.getUserFlow = exports.getUserType = exports.refreshToken = exports.UserType = exports.UserFlow = void 0;
/* eslint-disable no-unused-vars */
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const react_1 = require("react");
const requests_1 = require("../requests");
const catalog = {
    id: '000000000000000000000000',
    name: 'catalog',
    identification: 'catalog',
    type: 'API',
};
exports.catalog = catalog;
var UserFlow;
(function (UserFlow) {
    UserFlow[UserFlow["base"] = 0] = "base";
    UserFlow[UserFlow["last"] = 1] = "last";
    UserFlow[UserFlow["current"] = 2] = "current";
})(UserFlow = exports.UserFlow || (exports.UserFlow = {}));
var UserType;
(function (UserType) {
    UserType[UserType["none"] = 0] = "none";
    UserType[UserType["base"] = 1] = "base";
    UserType[UserType["client"] = 2] = "client";
    UserType[UserType["regular"] = 3] = "regular";
    UserType[UserType["seller"] = 4] = "seller";
})(UserType = exports.UserType || (exports.UserType = {}));
const getTTL = async (currentToken, offset) => {
    offset = offset || 1000;
    let decode = await jsonwebtoken_1.default.decode(currentToken || '');
    let exp = decode?.exp * 1000;
    let now = new Date().getTime();
    let ttl = exp - now - offset;
    return ttl;
};
const getStorageToken = (storage) => {
    const currentStorage = 'current' + storage;
    const isBrowser = typeof window !== 'undefined';
    const token = isBrowser
        ? localStorage.getItem(currentStorage) || undefined
        : undefined;
    return token;
};
exports.getStorageToken = getStorageToken;
const refreshSingleToken = async (storage, token, setToken, setUser, currentTimeout, setCurrentTimeout, timeoutFunction, setTimeoutFunction, address, path, data, offset, refreshMethod) => {
    let receivedToken;
    const currentStorage = 'current' + storage;
    token = token
        ? token
        : getStorageToken(storage);
    let ttl = await getTTL(token, offset);
    const newTimeoutFuntion = timeoutFunction
        ? timeoutFunction
        : (token) => {
            refreshSingleToken(storage, token, setToken, setUser, currentTimeout, setCurrentTimeout, timeoutFunction, setTimeoutFunction, address, path, data, offset, refreshMethod);
        };
    // console.log('address: ' + address);
    if (address || path || ttl <= 0) {
        clearTimeout(currentTimeout);
        // console.log('ttl: ' + ttl, address, path, token);
        const received = await (0, requests_1.request)(address || '', refreshMethod || 'post', path, token || undefined, data);
        receivedToken = received?.data?.token || received?.token || received || '';
        // console.log('receivedToken:', receivedToken);
        // console.log(currentStorage);
        // console.log('localStorage' + localStorage);
        ttl = await getTTL(receivedToken, offset);
        // console.log('ttl:', ttl);
        if (ttl > 0) {
            setTimeoutFunction?.((token) => newTimeoutFuntion(token));
            setCurrentTimeout?.(setTimeout(newTimeoutFuntion, ttl));
        }
        else {
            receivedToken = '';
        }
    }
    else {
        clearTimeout(currentTimeout);
        setTimeoutFunction?.((token) => newTimeoutFuntion(token));
        setCurrentTimeout?.(setTimeout(newTimeoutFuntion, ttl));
        receivedToken = token || '';
    }
    if (receivedToken == undefined || receivedToken?.trim() == '')
        receivedToken = '';
    const user = receivedToken == '' || receivedToken == undefined
        ? undefined
        : await jsonwebtoken_1.default.decode(receivedToken);
    // console.log('pre setToken receivedToken:', receivedToken);
    // console.log('pre setToken user:', user);
    receivedToken = receivedToken === '' ? undefined : receivedToken;
    setToken?.(receivedToken);
    if (receivedToken)
        localStorage.setItem(currentStorage, receivedToken);
    else
        localStorage.removeItem(currentStorage);
    setUser?.(user);
    // console.log('final receivedToken:', receivedToken);
    return receivedToken;
};
const refreshToken = async (token, setToken, setUser, timeout, setTimeout, timeoutFunction, setTimeoutFunction, address, path, data, offset, refreshMethod) => {
    let receivedToken;
    if (token(UserFlow.base) == undefined) {
        // console.log('base token is undefined');
        receivedToken = await refreshSingleToken(UserFlow.base, token(UserFlow.base), (newToken) => setToken?.(UserFlow.base, newToken), (newUser) => setUser?.(UserFlow.base, newUser), timeout?.(UserFlow.base), (newTimeout) => setTimeout?.(UserFlow.base, newTimeout), (token) => timeoutFunction?.(UserFlow.base, token), (newTimeoutFunction) => setTimeoutFunction?.(UserFlow.base, newTimeoutFunction), address, path, data, offset, refreshMethod);
    }
    const currentToken = token(UserFlow.current);
    const currentTimeout = timeout?.(UserFlow.current);
    // console.log('last refreshSingleToken');
    receivedToken = await refreshSingleToken(UserFlow.last, currentToken, (newToken) => setToken?.(UserFlow.last, newToken), (newUser) => setUser?.(UserFlow.last, newUser), currentTimeout, (newTimeout) => setTimeout?.(UserFlow.last, newTimeout), (token) => timeoutFunction?.(UserFlow.base, token), (newTimeoutFunction) => setTimeoutFunction?.(UserFlow.base, newTimeoutFunction), undefined, undefined, undefined, undefined, refreshMethod);
    // console.log('current refreshSingleToken');
    receivedToken = await refreshSingleToken(UserFlow.current, currentToken, (newToken) => setToken?.(UserFlow.current, newToken), (newUser) => setUser?.(UserFlow.current, newUser), timeout?.(UserFlow.current), (newTimeout) => setTimeout?.(UserFlow.current, newTimeout), (token) => timeoutFunction?.(UserFlow.base, token), (newTimeoutFunction) => setTimeoutFunction?.(UserFlow.base, newTimeoutFunction), address, path, data, offset, refreshMethod);
    return receivedToken;
};
exports.refreshToken = refreshToken;
const signOut = async (token, setToken, setUser, timeout, setTimeout, timeoutFunction, setTimeoutFunction, offset, refreshMethod, clear) => {
    if (clear) {
        localStorage.removeItem('current' + UserFlow.base);
        localStorage.removeItem('current' + UserFlow.current);
        localStorage.removeItem('current' + UserFlow.last);
        return undefined;
    }
    const baseToken = token(UserFlow.base);
    const lastToken = token(UserFlow.last);
    // console.log('signOut', baseToken, lastToken);
    let receivedToken = await refreshSingleToken(UserFlow.last, baseToken, (newToken) => setToken?.(UserFlow.last, newToken), (newUser) => setUser?.(UserFlow.last, newUser), timeout?.(UserFlow.last), (newTimeout) => setTimeout?.(UserFlow.last, newTimeout), (token) => timeoutFunction?.(UserFlow.base, token), (newTimeoutFunction) => setTimeoutFunction?.(UserFlow.base, newTimeoutFunction), undefined, undefined, undefined, offset, refreshMethod);
    // console.log('receivedToken 0', receivedToken);
    receivedToken = await refreshSingleToken(UserFlow.current, lastToken, (newToken) => setToken?.(UserFlow.current, newToken), (newUser) => setUser?.(UserFlow.current, newUser), timeout?.(UserFlow.current), (newTimeout) => setTimeout?.(UserFlow.current, newTimeout), (token) => timeoutFunction?.(UserFlow.last, token), (newTimeoutFunction) => setTimeoutFunction?.(UserFlow.last, newTimeoutFunction), undefined, undefined, undefined, offset, refreshMethod);
    // console.log('receivedToken 1', receivedToken);
    return receivedToken;
};
exports.signOut = signOut;
const getUserType = (user) => {
    // console.log('getUserType user:', user);
    return user?.level != undefined || user?.levelId != undefined
        ? UserType.regular
        : typeof user != 'string' && user?.active
            ? UserType.seller
            : user?.id != undefined
                ? user.id !== catalog.id ||
                    user.identification !== catalog.identification ||
                    user.name !== catalog.name
                    ? UserType.client
                    : UserType.base
                : UserType.none;
};
exports.getUserType = getUserType;
const getUserFlow = (userType) => {
    switch (userType) {
        case UserType.client:
        case UserType.regular:
            return UserFlow.current;
        case UserType.seller:
            return UserFlow.last;
        default:
            return UserFlow.base;
    }
};
exports.getUserFlow = getUserFlow;
const createUserContext = (value) => (0, react_1.createContext)(value);
exports.createUserContext = createUserContext;
const isSignedIn = (element, userTypes) => {
    // console.log('isSignedIn element:', element, userTypes);
    let signed = false;
    if (userTypes)
        for (let index = 0; index < (userTypes?.length || 0) && signed == false; index++) {
            const userType = userTypes?.[index];
            switch (userType) {
                case UserType.client:
                    signed =
                        !element?.active &&
                            element?.id != undefined &&
                            (element?.id !== catalog.id ||
                                element?.identification !== catalog.identification ||
                                element?.name !== catalog.name);
                    break;
                case UserType.regular:
                    signed = element?.levelId != undefined || element?.level != undefined;
                    break;
                case UserType.seller:
                    signed = element?.active;
                    break;
                case UserType.none:
                    signed = element != undefined;
                    break;
                default:
                    signed =
                        element?.id == catalog.id &&
                            element?.identification == catalog.identification &&
                            element?.name == catalog.name;
                    break;
            }
        }
    return signed;
};
exports.isSignedIn = isSignedIn;
//# sourceMappingURL=user.js.map