"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getImage = exports.urltoFile = exports.resizeImage = exports.useQuery = exports.exists = void 0;
const react_1 = require("react");
const react_router_dom_1 = require("react-router-dom");
const exists = (array, value) => {
    let find = array?.findIndex?.((element) => element === value);
    let has = find != undefined && find > -1;
    return has;
};
exports.exists = exists;
const useQuery = () => {
    const { search } = (0, react_router_dom_1.useLocation)();
    const query = (0, react_1.useMemo)(() => new URLSearchParams(search), [search]);
    return query;
};
exports.useQuery = useQuery;
const urltoFile = async (url, filename, mimeType) => {
    return fetch(url)
        .then(function (res) {
        return res.arrayBuffer();
    })
        .then(function (buf) {
        return new File([buf], filename, { type: mimeType });
    });
};
exports.urltoFile = urltoFile;
const getImage = async (file) => {
    const image = new Image();
    image.src = URL.createObjectURL(file);
    return new Promise((resolve) => {
        image.onload = (a) => {
            const imgData = {
                width: a?.currentTarget?.width,
                height: a?.currentTarget?.height,
                img: image,
            };
            resolve(imgData);
        };
    });
};
exports.getImage = getImage;
const resizeImage = async (originalFile, targetFileSizeKb = (originalFile.size || 0) / 1000) => {
    // console.log('resizeImage');
    let file = originalFile;
    let currentSize = (originalFile.size || 0) / 1000;
    let targetSize = targetFileSizeKb;
    let factor = Math.sqrt(targetSize / currentSize);
    // console.log('Factor:', factor);
    // console.log('sizes:', currentSize, targetSize);
    return new Promise(async (resolve) => {
        if (currentSize <= targetSize)
            return resolve(originalFile); // File is already smaller
        const url = await URL.createObjectURL(file);
        const canvas = document.createElement('canvas');
        const img = new Image();
        //console.log(file);
        img.src = url;
        img.onload = async (nImg) => {
            const target = nImg?.currentTarget;
            if (canvas && target?.width && target?.height) {
                const width = target.width;
                const height = target.height;
                canvas.width = width;
                canvas.height = height;
                const context = canvas.getContext('2d');
                if (context) {
                    const image = await getImage(file);
                    context.drawImage(image.img, 0, 0);
                    const newWidth = Math.round(width * factor);
                    const newHeight = Math.round(height * factor);
                    canvas.width = newWidth;
                    canvas.height = newHeight;
                    context.scale(newWidth / width, newHeight / height);
                    context.drawImage(image.img, 0, 0);
                    file = await urltoFile(canvas.toDataURL(), originalFile.type.replace('/', '.'), originalFile.type);
                    // console.log('NEW:', file.size / 1000);
                }
            }
            return resolve(file);
        };
    });
};
exports.resizeImage = resizeImage;
//# sourceMappingURL=util.js.map